@@ -13,7 +13,8 @@ field tied_file => undef;
 sub file {
     my $self = shift;
     bless $self, __PACKAGE__;
-    $self->name(shift) if @_;
+    # should we die here if $self->name is already set and there are args?
+    $self->name( $self->_spec_class->catfile( @_ ) ) if @_;
     return $self->_init;
 }
 
@@ -56,7 +57,7 @@ sub assert_tied_file {
     my $self = shift;
     return $self->tied_file || do {
         eval {require Tie::File};
-        $self->throw("Tie::File required for file array operations:\n$@") 
+        $self->throw("Tie::File required for file array operations:\n$@")
           if $@;
         my $array_ref = do { my @array; \@array };
         my $name = $self->pathname;
@@ -81,7 +82,7 @@ sub open {
     push @args, $self->perms if defined $self->perms;
     if (defined $self->pathname) {
         $self->io_handle(IO::File->new);
-        $self->io_handle->open($self->pathname, @args) 
+        $self->io_handle->open($self->pathname, @args)
           or $self->throw($self->open_msg);
     }
     elsif (defined $self->_handle and
@@ -240,7 +241,9 @@ sub overload_file_as_scalar {
     return \$scalar;
 }
 
-=head1 NAME 
+=encoding utf8
+
+=head1 NAME
 
 IO::All::File - File Support for IO::All
 
@@ -252,11 +255,13 @@ See L<IO::All>.
 
 =head1 AUTHOR
 
-Brian Ingerson <INGY@cpan.org>
+Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
+Copyright (c) 2004. Brian Ingerson.
+
+Copyright (c) 2006, 2008. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
