@@ -4,14 +4,6 @@ use warnings;
 use IO::All::Base -base;
 use Fcntl qw(:flock);
 
-sub absolute {
-    my $self = shift;
-    $self->pathname(File::Spec->rel2abs($self->pathname))
-      unless $self->is_absolute;
-    $self->is_absolute(1);
-    return $self;
-}
-
 sub exists { my $self = shift; -e $self->name }
 
 sub filename {
@@ -21,10 +13,25 @@ sub filename {
     return $filename;
 }
 
+sub ext {
+   my $self = shift;
+
+   return $1 if $self->filename =~ m/\.([^\.]+)$/
+}
+{
+    no warnings 'once';
+    *extension = \&ext;
+}
+
+sub mimetype {
+   require File::MimeInfo;
+   return File::MimeInfo::mimetype($_[0]->filename)
+}
+
 sub is_absolute {
     my $self = shift;
     return *$self->{is_absolute} = shift if @_;
-    return *$self->{is_absolute} 
+    return *$self->{is_absolute}
       if defined *$self->{is_absolute};
     *$self->{is_absolute} = IO::All::is_absolute($self) ? 1 : 0;
 }
@@ -100,7 +107,9 @@ sub utime {
     return $self;
 }
 
-=head1 NAME 
+=encoding utf8
+
+=head1 NAME
 
 IO::All::Filesys - File System Methods Mixin for IO::All
 
@@ -116,9 +125,9 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
+Copyright (c) 2004. Brian Ingerson.
 
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
+Copyright (c) 2006, 2008. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
